=== modified file 'Vagrantfile'
--- Vagrantfile	2012-12-12 22:38:29 +0000
+++ Vagrantfile	2012-12-13 22:48:12 +0000
@@ -12,7 +12,7 @@
     ltp.ssh.max_tries = 50
     ltp.ssh.timeout = 300
 
-    ltp.vm.share_folder("v-root", "/home/vagrant/ltp", ".", :nfs => true)
+    ltp.vm.share_folder("v-root", "/home/vagrant/ltp", ".")
 
     ltp.vm.provision :puppet do |puppet|
         puppet.manifests_path = "puppet/manifests"

=== modified file 'loco_directory/articles/models.py'
--- loco_directory/articles/models.py	2012-12-12 23:07:32 +0000
+++ loco_directory/articles/models.py	2012-12-13 22:48:12 +0000
@@ -7,6 +7,8 @@
 
 from django.db import models
 from django.conf import settings
+from django.template.defaultfilters import slugify
+
 
 from teams.models import Team
 from userprofiles.models import UserProfile
@@ -119,3 +121,7 @@
 
     def __unicode__(self):
         return u'%s (%s)' % (self.title, self.author)
+
+    @models.permalink
+    def get_absolute_url(self):
+        return ('article-detail', [str(self.id), slugify(self.title)])

=== added file 'loco_directory/articles/urls.py'
--- loco_directory/articles/urls.py	1970-01-01 00:00:00 +0000
+++ loco_directory/articles/urls.py	2012-12-13 22:48:12 +0000
@@ -0,0 +1,7 @@
+# -*- coding: utf-8 -*-
+from django.conf.urls.defaults import *
+
+urlpatterns = patterns('',
+    url(r'^(?P<article_id>\d+)-(?P<article_slug>[a-zA-Z0-9\-\.\+?]+)/$',
+         'articles.views.article_detail', name='article-detail'),
+)

=== modified file 'loco_directory/articles/views.py'
--- loco_directory/articles/views.py	2011-06-01 22:19:20 +0000
+++ loco_directory/articles/views.py	2012-12-13 22:48:12 +0000
@@ -1,2 +1,17 @@
-# Create your views here.
-
+# -*- coding: utf-8 -*-
+from django.shortcuts import (render_to_response, get_object_or_404)
+from django.template import RequestContext
+from .models import Article
+
+
+def article_detail(request, article_id, article_slug=None):
+    """
+    detailed view for an article
+    """
+    article = get_object_or_404(Article, pk=article_id)
+
+    context = {
+        'article': article,
+    }
+    return render_to_response('articles/article_detail.html',
+                                         context, RequestContext(request))

=== modified file 'loco_directory/media/css/styles.css'
--- loco_directory/media/css/styles.css	2012-12-13 20:46:23 +0000
+++ loco_directory/media/css/styles.css	2012-12-13 22:48:12 +0000
@@ -1221,6 +1221,17 @@
     margin-bottom: 0px;
 }
 
+.blog-entry-text ol, ul {
+    text-align:justify;
+    font-size: 13px;
+    line-height: 1.4;
+}
+
+.blog-entry-text img {
+    max-width: 658px;
+}
+
+
 .rsvp-link {
     margin: 0 auto;
     margin-top: 10px!important;

=== added directory 'loco_directory/templates/articles'
=== added file 'loco_directory/templates/articles/article_detail.html'
--- loco_directory/templates/articles/article_detail.html	1970-01-01 00:00:00 +0000
+++ loco_directory/templates/articles/article_detail.html	2012-12-13 22:48:12 +0000
@@ -0,0 +1,66 @@
+{% extends "base.html" %}
+{% load i18n %}
+
+{% block page_name %}{{ article.title }}{% endblock %}
+
+{% block extrahead %}{{ block.super }}
+<meta property="fb:app_id" content="127188230723188"/>
+<meta property="og:title" content="{{ article.title }}" />
+<meta property="og:description" content="{{ article.description|linebreaks|striptags }}" />
+<meta property="og:url" content="http://loco.ubuntu.com{{ article.get_absolute_url }}"/>
+<meta property="og:image" content="http://loco.ubuntu.com/media/images/cof_orange_hex1.png"/>
+<meta property="og:site_name" content="Loco Team Portal"/>
+<meta property="og:type" content="article"/>
+{% endblock %}
+
+
+{% block content %}
+<div class="row">
+    <section class="span-9">
+                <article class="blog-entry">
+                    {% if article.source.team %}
+                        <img class="blog-entry-image" src="{{ article.source.team.mugshot_url }}" />
+                    {% else %}
+                        {% if article.source.user %}
+                         <img class="blog-entry-image" src="{{ article.source.user.mugshot }}" />
+                        {% endif %}
+                    {% endif %}
+                    <h4 class="blog-entry-title"><a href="{{ article.link }}" target="_blank">{{ article.title }}</a></h4>
+                    <div class="blog-entry-author">
+                        {% if article.source.team %}
+                            <a class="team" href="{% url team-detail article.source.team %}" target="_blank">{{ article.source.team.name }}</a>
+                        {% endif %}
+                        {% if article.source.user %}
+                            {% if article.source.team %}, {% endif %}
+                            <a class="user" href="{% url profile-detail article.source.user.user.username %}" target="_blank">{{ article.source.user }}</a>
+                        {% endif %}
+                    </div>
+                    <div class="share">
+                        <div id="fb-root"></div>
+                        <script>(function(d, s, id) {
+                              var js, fjs = d.getElementsByTagName(s)[0];
+                              if (d.getElementById(id)) {return;}
+                              js = d.createElement(s); js.id = id;
+                              js.src = "//connect.facebook.net/en_US/all.js#xfbml=1&appId=127188230723188";
+                              fjs.parentNode.insertBefore(js, fjs);
+                            }(document, 'script', 'facebook-jssdk'));</script>
+                        <script type="text/javascript" src="https://apis.google.com/js/plusone.js"></script>
+                        <script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
+                        <g:plusone size="medium"></g:plusone>
+                        <a href="http://twitter.com/share" class="twitter-share-button" data-lang="en">Tweet</a>
+                        <div class="fb-like" data-href="http://loco.ubuntu.com{{ article.get_absolute_url }}" data-send="false" data-layout="button_count" data-width="40" data-show-faces="false" data-font="arial"></div>
+                        </div>
+                    <div class="blog-entry-text">
+                        <p>
+                            {% autoescape off %}
+                                {{ article.content|safe }}
+                            {% endautoescape %}
+                        </p>
+                        <p class="more">
+                            <a href="{{ article.link }}" target="_blank">{% trans 'Read the original post' %} ›</a>
+                        </p>
+                    </div>
+                </article>
+    </section>
+</div>
+{% endblock %}

=== modified file 'loco_directory/templates/index.html'
--- loco_directory/templates/index.html	2012-12-12 22:44:53 +0000
+++ loco_directory/templates/index.html	2012-12-13 22:48:12 +0000
@@ -69,7 +69,7 @@
                  <img class="blog-entry-image" src="{{ article.source.user.mugshot }}" />
                 {% endif %}
             {% endif %}
-            <h4 class="blog-entry-title"><a href="{{ article.link }}" target="_blank">{{ article.title }}</a></h4>
+            <h4 class="blog-entry-title"><a href="{{ article.get_absolute_url }}">{{ article.title }}</a></h4>
             <div class="blog-entry-author">
                 {% if article.source.team %}
                     <a class="team" href="{% url team-detail article.source.team %}" target="_blank">{{ article.source.team.name }}</a>
@@ -79,11 +79,10 @@
                     <a class="user" href="{% url profile-detail article.source.user.user.username %}" target="_blank">{{ article.source.user }}</a>
                 {% endif %}
             </div>
-
             <div class="blog-entry-text">
                 <p>{{ article.content|safe|striptags|truncatewords_html:100 }}</p>
                 <p class="more">
-                    <a href="{{ article.link }}" target="_blank">{% trans 'Read More' %} ›</a>
+                    <a href="{{ article.get_absolute_url }}">{% trans 'Read More' %} ›</a>
                 </p>
             </div>
         </article>
@@ -92,7 +91,6 @@
 <section class="span-4 last">
     <h2>{% if team_event_count %}{{ team_event_count }} {% endif %}{% trans "Upcoming Events" %}</h2>
     <a href="{% url event-list %}"><img src="{{ MEDIA_URL }}img/home-map.png" /></a>
-
     <h2>{% trans "Latest social messages" %}</h2>
     <div class="twidenash" id="locoteams"></div>
 </section>

=== modified file 'loco_directory/urls.py'
--- loco_directory/urls.py	2012-12-09 15:08:12 +0000
+++ loco_directory/urls.py	2012-12-13 22:48:12 +0000
@@ -29,6 +29,7 @@
     url(r'^admin/(.*)', admin.site.root),
     url(r'^data/xml', 'teams.views.xml_team_data', name='xml_team_data'),
     url(r'^teams/', include('teams.urls')),
+    url(r'^planet/', include('articles.urls')),
     url(r'^events/venues/', include('venues.urls')),
     url(r'^events/', include('events.urls')),
     url(r'^meetings/', include('meetings.urls')),

